@@ -16,6 +16,7 @@
 #define SYS_INTERIX	8
 #define SYS_OPENVMS	9
 #define SYS_DOS		10
+#define SYS_HAIKU	11
 
 /* hardcoded limit of 10 OSes in default.c */
 
@@ -29,7 +30,7 @@
 #define WIN
 #elif defined(__INTERIX)
 #define INTERIX
-#elif defined(__BEOS__) || defined(__HAIKU__)
+#elif defined(__BEOS__)
 #define BEOS
 #elif defined(__riscos__)
 #define RISCOS
@@ -41,6 +42,8 @@
 #define OPENVMS
 #elif defined(__DJGPP)
 #define DOS
+#elif defined(__HAIKU__)
+#define HAIKU
 #else
 #define UNIX
 #endif
@@ -60,8 +63,6 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define SHARED_CONFIG_DIR "/etc/"
 #ifdef HAVE_SYS_UN_H
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
 #endif
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
@@ -81,6 +82,7 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define DOS_FS_8_3
 #define NO_FILE_SECURITY
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
 #define ASSOC_CONS_XWIN
 #define DISABLE_SMB
 
@@ -88,7 +90,7 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 
 static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define NEWLINE "\r\n"
-/*#define NO_ASYNC_LOOKUP*/
+#define NO_ASYNC_LOOKUP	/* Cygwin 3.5.3 has some bug that async lookup doesn't work when started from a detached thread */
 #define SYSTEM_ID SYS_WIN_32
 #define SYSTEM_NAME "Win32"
 #define DEFAULT_SHELL "cmd.exe"
@@ -107,8 +109,6 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #endif
 #if defined(HAVE_SYS_UN_H) && !defined(_UWIN)
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
 #endif
 #if defined(_UWIN)
 #define USE_WIN32_HEAP
@@ -116,6 +116,9 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #ifdef USE_WIN32_HEAP
 #define NO_FORK_ON_EXIT
 #endif
+#ifndef __CYGWIN__
+#define OS_NO_SYSTEM_CHARSET
+#endif
 
 #elif defined(INTERIX)
 
@@ -132,11 +135,10 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define SHARED_CONFIG_DIR "/etc/"
 #ifdef HAVE_SYS_UN_H
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
 #endif
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
+#define OS_NO_SYSTEM_CHARSET
 
 #elif defined(BEOS)
 
@@ -153,7 +155,10 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NO_CTRL_Z
 #define SHARED_CONFIG_DIR "/etc/"
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
 #define ASSOC_BLOCK
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -176,7 +181,10 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define NO_CTRL_Z
 #define NO_FILE_SECURITY
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
 #define DISABLE_SMB
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #elif defined(ATHEOS)
 
@@ -191,7 +199,6 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define DEFAULT_SHELL "/bin/sh"
 #define GETSHELL getenv("SHELL")
 #define SHARED_CONFIG_DIR "/etc/"
-#define DONT_USE_AF_UNIX
 #define NO_FORK_ON_EXIT
 #define ASSOC_BLOCK
 
@@ -205,14 +212,11 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define GETSHELL "LIB.:/SHELL.EXE"
 #define NO_CTRL_Z
 #define SHARED_CONFIG_DIR "ETC.:/"
-#ifdef HAVE_SYS_UN_H
-#define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
-#endif
 #define NO_FORK_ON_EXIT
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #elif defined(OPENVMS)
 
@@ -227,12 +231,13 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #ifndef HAVE_PTHREADS
 #define HAVE_PTHREADS
 #endif
-#define DONT_USE_AF_UNIX
 #define NO_CTRL_Z
 #define NO_FORK_ON_EXIT
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
 #define DISABLE_SMB
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #elif defined(DOS)
 
@@ -248,10 +253,26 @@ static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define DOS_FS
 #define DOS_FS_8_3
 #define NO_FILE_SECURITY
-#define DONT_USE_AF_UNIX
 #define NO_FORK_ON_EXIT
 #define DISABLE_SMB
 
+#elif defined(HAIKU)
+
+static inline int dir_sep(unsigned char x) { return x == '/'; }
+#define NEWLINE "\n"
+#define FS_UNIX_RIGHTS
+#define FS_UNIX_SOFTLINKS
+#define FS_UNIX_USERS
+#define SYSTEM_ID SYS_HAIKU
+#define SYSTEM_NAME "Haiku"
+#define DEFAULT_SHELL "/bin/sh"
+#define GETSHELL getenv("SHELL")
+#define NO_CTRL_Z
+#define SET_WINDOW_TITLE_UTF_8
+#define SHARED_CONFIG_DIR "/etc/"
+#define USE_AF_UNIX
+#define ASSOC_BLOCK
+
 #endif
 
 #ifdef FS_UNIX_USERS
