@@ -125,18 +125,21 @@ int can_read(int fd)
 }
 
 
-int close_stderr(void)
+int close_std_handle(int std)
 {
 #ifndef DOS
 	int n, h, rs;
-	fflush(stderr);
+	if (std == 1)
+		fflush(stdout);
+	if (std == 2)
+		fflush(stderr);
 	n = c_open(cast_uchar "/dev/null", O_WRONLY | O_NOCTTY);
 	if (n == -1)
 		goto fail1;
-	h = c_dup(2);
+	h = c_dup(std);
 	if (h == -1)
 		goto fail2;
-	EINTRLOOP(rs, dup2(n, 2));
+	EINTRLOOP(rs, dup2(n, std));
 	if (rs == -1)
 		goto fail3;
 	EINTRLOOP(rs, close(n));
@@ -151,14 +154,17 @@ fail1:
 	return -1;
 }
 
-void restore_stderr(int h)
+void restore_std_handle(int std, int h)
 {
 #ifndef DOS
 	int rs;
-	fflush(stderr);
+	if (std == 1)
+		fflush(stdout);
+	if (std == 2)
+		fflush(stderr);
 	if (h == -1)
 		return;
-	EINTRLOOP(rs, dup2(h, 2));
+	EINTRLOOP(rs, dup2(h, std));
 	EINTRLOOP(rs, close(h));
 #endif
 }
@@ -579,6 +585,16 @@ void kill_timer(struct timer *tm)
 #endif
 }
 
+int verify_handle(int fd)
+{
+#if defined(USE_POLL) && defined(USE_LIBEVENT)
+	if (!event_enabled)
+#endif
+		if (fd >= (int)FD_SETSIZE)
+			return -1;
+	return 0;
+}
+
 void (*get_handler(int fd, int tp))(void *)
 {
 	if (fd < 0)
@@ -596,7 +612,7 @@ void (*get_handler(int fd, int tp))(void *)
 void *get_handler_data(int fd)
 {
 	if (fd < 0)
-		internal_error("get_handler: handle %d", fd);
+		internal_error("get_handler_data: handle %d", fd);
 	if (fd >= w_max)
 		return NULL;
 	return threads[fd].data;
@@ -701,8 +717,8 @@ struct signal_handler {
 static volatile int signal_mask[NUM_SIGNALS];
 static volatile struct signal_handler signal_handlers[NUM_SIGNALS];
 
-pid_t signal_pid;
-int signal_pipe[2];
+static pid_t signal_pid;
+int signal_pipe[2] = { -1, -1 };
 
 SIGNAL_HANDLER static void got_signal(int sig)
 {
@@ -921,7 +937,7 @@ void omp_end(void)
 
 #endif
 
-void reinit_child(int free_libevent)
+void reinit_child(void)
 {
 #if !defined(NO_SIGNAL_HANDLERS)
 	signal_pid = getpid();
@@ -931,12 +947,6 @@ void reinit_child(int free_libevent)
 #ifdef HAVE_EVENT_REINIT
 		if (event_reinit(event_base))
 			fatal_exit("ERROR: event_reinit failed: %s", strerror(errno));
-#ifdef HAVE_EVENT_BASE_FREE
-		if (free_libevent) {
-			event_base_free(event_base);
-			event_enabled = 0;
-		}
-#endif
 #endif
 	}
 #endif
@@ -995,6 +1005,7 @@ void select_loop(void (*init)(void))
 				redraw_all_terminals();
 			}
 			if (terminate_loop) break;
+			test_detach_console();
 			do_event_loop(EVLOOP_ONCE);
 		}
 		nopr();
@@ -1009,6 +1020,7 @@ void select_loop(void (*init)(void))
 		check_signals();
 		check_timers();
 		if (!F) redraw_all_terminals();
+		test_detach_console();
 #ifdef OS_BAD_SIGNALS
 	/* Cygwin has buggy signals that sometimes don't interrupt select.
 	   So don't wait indefinitely in it. */
