@@ -32,16 +32,6 @@
 #define NO_IE
 #endif
 
-#define LINKS_MANUAL_URL		(!strcmp(cast_const_char language_name(get_current_language()),"Czech") || !strcmp(cast_const_char language_name(get_current_language()),"Slovak")?\
-					"http://links.twibright.com/user.html":\
-					"http://links.twibright.com/user_en.html")
-#define LINKS_HOMEPAGE_URL		(!strcmp(cast_const_char language_name(get_current_language()),"Czech") || !strcmp(cast_const_char language_name(get_current_language()),"Slovak")?\
-					"http://links.twibright.com/index_cz.php":\
-					"http://links.twibright.com/")
-#define LINKS_CALIBRATION_URL		(!strcmp(cast_const_char language_name(get_current_language()),"Czech") || !strcmp(cast_const_char language_name(get_current_language()),"Slovak")?\
-					"http://links.twibright.com/kalibrace.html":\
-					"http://links.twibright.com/calibration.html")
-
 #define LINKS_SOCK_NAME			"socket"
 #define LINKS_ANONYMOUS_SOCK_SUFFIX	"-a"
 #define LINKS_PORT			23755
@@ -112,7 +102,6 @@
 #define COLOR_TITLE			COL(007)
 #define COLOR_STATUS			COL(070)
 
-#define G_BFU_DEFAULT_FONT		"century-medium-roman-serif-vari"
 #define G_BFU_DEFAULT_FONT_SIZE		16
 #define G_DEFAULT_BFU_FG_COLOR		0x000000
 #define G_DEFAULT_BFU_BG_COLOR		0xe0e0e0
@@ -149,8 +138,10 @@
 #define G_DIALOG_BUTTON_L		"[ "
 #define G_DIALOG_BUTTON_R		" ]"
 
-#define G_LEFT_ARROW			" \342\206\220 "
-#define MENU_SUBMENU			(!F ? cast_uchar ">" : cast_uchar "\342\206\222")
+#define G_LEFT_ARROW			"\342\206\220"
+#define G_RIGHT_ARROW			"\342\206\222"
+#define MENU_SUBMENU			(!F ? cast_uchar ">" : cast_uchar G_RIGHT_ARROW)
+#define CERT_RIGHT_ARROW		(!F ? cast_uchar " -> " : cast_uchar " " G_RIGHT_ARROW " ")
 
 #define G_SCROLL_BAR_WIDTH		12
 #define G_SCROLL_BAR_MIN_SIZE		20
@@ -173,10 +164,20 @@
 
 #define ESC_TIMEOUT			200
 
+#ifdef OPENVMS
+#define TERMINAL_POLL_TIMEOUT		3000
+#else
+#define TERMINAL_POLL_TIMEOUT		1000
+#endif
+
+#define WIN32_REPAINT_IDLE_TIME		100
+#define WIN32_REPAINT_BUSY_TIME		1000
+
 #define DISPLAY_TIME_MIN		200
 #define DISPLAY_TIME_MAX_FIRST		1000
 #define DISPLAY_TIME			15
 #define IMG_DISPLAY_TIME		7
+#define DISPLAY_FORMATTING_STATUS	500
 
 #define STAT_UPDATE_MIN			100
 #define STAT_UPDATE_MAX			1000
@@ -194,7 +195,7 @@
 #define HTML_DEFAULT_TEXTAREA_WIDTH	40
 #define HTML_DEFAULT_TEXTAREA_HEIGHT	7
 
-#define MAX_INPUT_URL_LEN		4096
+#define MAX_INPUT_URL_LEN		65536
 
 #ifdef DOS
 #define SPD_DISP_TIME			1000
@@ -212,9 +213,11 @@
  * (draw_bfu_element function in listedit.c)
  * BFU_ELEMENT_WIDTH is a size of one bfu element (doesn't depend on graphical/text mode)
  */
-#define BFU_GRX_WIDTH                 (G_BFU_FONT_SIZE>>1)
-#define BFU_ELEMENT_WIDTH             (gf_val(5,5*BFU_GRX_WIDTH))
-#define BFU_GRX_HEIGHT                        G_BFU_FONT_SIZE
+#define BFU_GRX_WIDTH			(G_BFU_FONT_SIZE >> 1)
+#define BFU_ELEMENT_WIDTH		(gf_val(5,5 * BFU_GRX_WIDTH))
+#define BFU_GRX_HEIGHT			G_BFU_FONT_SIZE
+
+#define USE_ITALIC
 
 /* higher number=more sensitive scrolling */
 /* used in list_event_handler in listedit.c */
