@@ -74,7 +74,19 @@ void add_bytes_to_str(unsigned char **s, int *l, unsigned char *a, size_t ll)
 	if (x >= old_length) {
 		/* Need to realloc */
 #ifdef HAVE___BUILTIN_CLZ
-#if !(defined(__tune_i386__) || defined(__tune_i486__) || defined(__tune_i586__) || defined(__tune_k6__) || defined(__tune_lakemont__) || (defined(__alpha__) && !defined(__alpha_cix__)) || (defined(__mips) && __mips < 32) || (defined(__ARM_ARCH) && __ARM_ARCH < 5) || (defined(__sparc__) && (!defined(__VIS__) || __VIS__ < 0x300)) || defined(__hppa) || defined(__sh__))
+#if !(									\
+	defined(__tune_i386__) ||					\
+	defined(__tune_i486__) ||					\
+	defined(__tune_i586__) ||					\
+	defined(__tune_k6__) ||						\
+	defined(__tune_lakemont__) ||					\
+	(defined(__alpha__) && !defined(__alpha_cix__)) ||		\
+	(defined(__mips) && __mips < 32) ||				\
+	(defined(__ARM_ARCH) && __ARM_ARCH < 5) ||			\
+	(defined(__sparc__) && (!defined(__VIS__) || __VIS__ < 0x300)) ||\
+	defined(__hppa) ||						\
+	(defined(__riscv) && !defined(__riscv_zbb)) ||			\
+	defined(__sh__))
 		if (!(sizeof(unsigned) & (sizeof(unsigned) - 1))) {
 			new_length = 2U << ((sizeof(unsigned) * 8 - 1)
 #ifdef __ICC
@@ -121,8 +133,25 @@ void add_unsigned_long_num_to_str(unsigned char **s, int *l, my_uintptr_t n)
 void add_num_to_str(unsigned char **s, int *l, off_t n)
 {
 	unsigned char a[64];
-	snzprint(a, 64, n);
-	add_to_str(s, l, a);
+	if (n >= 0 && n < 1000) {
+		unsigned sn = (unsigned)n;
+		unsigned char *p = a;
+		if (sn >= 100) {
+			*p++ = '0' + sn / 100;
+			sn %= 100;
+			goto d10;
+		}
+		if (sn >= 10) {
+			d10:
+			*p++ = '0' + sn / 10;
+			sn %= 10;
+		}
+		*p++ = '0' + sn;
+		add_bytes_to_str(s, l, a, p - a);
+	} else {
+		snzprint(a, 64, n);
+		add_to_str(s, l, a);
+	}
 }
 
 void add_knum_to_str(unsigned char **s, int *l, off_t n)
@@ -136,10 +165,11 @@ void add_knum_to_str(unsigned char **s, int *l, off_t n)
 
 long strtolx(unsigned char *c, unsigned char **end)
 {
+	char *end_c;
 	long l;
-	if (c[0] == '0' && upcase(c[1]) == 'X' && c[2]) l = strtol(cast_const_char(c + 2), (char **)(void *)end, 16);
-	else l = strtol(cast_const_char c, (char **)(void *)end, 10);
-	if (!*end) return l;
+	if (c[0] == '0' && upcase(c[1]) == 'X' && c[2]) l = strtol(cast_const_char(c + 2), &end_c, 16);
+	else l = strtol(cast_const_char c, &end_c, 10);
+	*end = cast_uchar end_c;
 	if (upcase(**end) == 'K') {
 		(*end)++;
 		if (l < -MAXINT / 1024) return -MAXINT;
@@ -157,17 +187,20 @@ long strtolx(unsigned char *c, unsigned char **end)
 
 my_strtoll_t my_strtoll(unsigned char *string, unsigned char **end)
 {
+	char *end_c;
 	my_strtoll_t f;
 	errno = 0;
 #if defined(HAVE_STRTOLL)
-	f = strtoll(cast_const_char string, (char **)(void *)end, 10);
+	f = strtoll(cast_const_char string, &end_c, 10);
 #elif defined(HAVE_STRTOQ)
-	f = strtoq(cast_const_char string, (char **)(void *)end, 10);
+	f = strtoq(cast_const_char string, &end_c, 10);
 #elif defined(HAVE_STRTOIMAX)
-	f = strtoimax(cast_const_char string, (char **)(void *)end, 10);
+	f = strtoimax(cast_const_char string, &end_c, 10);
 #else
-	f = strtol(cast_const_char string, (char **)(void *)end, 10);
+	f = strtol(cast_const_char string, &end_c, 10);
 #endif
+	if (end)
+		*end = cast_uchar end_c;
 	if (f < 0 || errno) return -1;
 	return f;
 }
@@ -282,4 +315,10 @@ int casestrstr(const unsigned char *h, const unsigned char *n)
 	return 0;
 }
 
-
+unsigned hash_string(unsigned char *u)
+{
+	unsigned hash = 0;
+	for (; *u; u++)
+		hash = hash * 0x11 + *u;
+	return hash;
+}
